@@ -1,7 +1,7 @@
 package HTTP::Engine;
 use Moose;
 use HTTP::Engine::Types::Core qw( Interface );
-our $VERSION = '0.0.7';
+our $VERSION = '0.0.8';
 use HTTP::Engine::Context;
 use HTTP::Engine::Request;
 use HTTP::Engine::Request::Upload;
@@ -126,13 +126,23 @@ currently supports the following:
 
 =over 4
 
-=item HTTP::Engine::Interface::CGI
+=item HTTP::Engine::Interface::ServerSimple
 
 =item HTTP::Engine::Interface::FastCGI
 
+=item HTTP::Engine::Interface::CGI
+
+=item HTTP::Engine::Interface::Test
+
+for test code interface
+
 =item HTTP::Engine::Interface::ModPerl
 
-=item HTTP::Engine::Interface::ServerSimple
+experimental
+
+=item HTTP::Engine::Interface::Standalone
+
+old style
 
 =back
 
@@ -176,10 +186,6 @@ Loads the given middleware into the HTTP::Engine.
 
 =back
 
-=head1 BRANCHES
-
-Moose branch L<http://svn.coderepos.org/share/lang/perl/HTTP-Engine/branches/moose/>
-
 =head1 AUTHOR
 
 Kazuhiro Osawa E<lt>ko@yappo.ne.jpE<gt>
@@ -198,6 +204,8 @@ dann
 
 typester (Interface::FCGI)
 
+lopnor
+
 =head1 SEE ALSO
 
 wiki page L<http://coderepos.org/share/wiki/HTTP%3A%3AEngine>
